pub struct UserDataOwned<T>(pub T);Expand description
A wrapper type that takes ownership of a userdata value.
It implements FromLua and can be used to receive a typed userdata from Lua by taking
ownership of it.
The original Lua userdata is marked as destructed and cannot be used further.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Debug> Debug for UserDataOwned<T>
impl<T: Debug> Debug for UserDataOwned<T>
Sourceimpl<T> Deref for UserDataOwned<T>
impl<T> Deref for UserDataOwned<T>
Sourceimpl<T> DerefMut for UserDataOwned<T>
impl<T> DerefMut for UserDataOwned<T>
Sourceimpl<T: Display> Display for UserDataOwned<T>
impl<T: Display> Display for UserDataOwned<T>